package userinterface;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Polygon;

import javax.swing.BorderFactory;
import javax.swing.JPanel;
/**
 * Solution from https://stackoverflow.com/questions/30356545/java-creating-a-jframe-using-gridlayout-with-mouse-interactive-jpanels
 * Added x, y and orientation as public class variables, so GUI can access them.
 * @author F. van Slooten
 *
 */
public class PixelPanel extends JPanel {

    private static final int PIXEL_SIZE = 10;
    
    public int x, y, orientation = -1;

    private Color backgroundColor;

    /**
     * Create a PixelPanel on given position (x,y).
     * It is a square with a default size as set by it's class-variable PIXEL_SIZE.
     * @param x
     * @param y
     */
    public PixelPanel(int x, int y) {
    	this.x = x;
    	this.y = y;
        this.backgroundColor = Color.WHITE;
        this.setBorder(BorderFactory.createLineBorder(Color.BLACK));
        this.setPreferredSize(new Dimension(PIXEL_SIZE, PIXEL_SIZE));
    }

    /**
     * Return the current background color.
     * @return
     */
    public Color getBackgroundColor() {
        return backgroundColor;
    }

    /**
     * Set the background color of the panel.
     * @param backgroundColor
     */
    public void setBackgroundColor(Color backgroundColor) {
        this.backgroundColor = backgroundColor;
        repaint();
    }

    /**
     * Paint the panel (a filled rectangle).
     */
    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);

        g.setColor(getBackgroundColor());
        g.fillRect(0, 0, getWidth(), getHeight());
    }
}
